emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master cfdce1a19fa 3/3: ; Fix documentation of last change.


From: Eli Zaretskii
Subject: master cfdce1a19fa 3/3: ; Fix documentation of last change.
Date: Sat, 22 Jul 2023 11:50:17 -0400 (EDT)

branch: master
commit cfdce1a19fa8a845b78e535b510932df945598ad
Author: Eli Zaretskii <eliz@gnu.org>
Commit: Eli Zaretskii <eliz@gnu.org>

    ; Fix documentation of last change.
    
    * src/xdisp.c (syms_of_xdisp):
    * src/dispnew.c (syms_of_display):
    * doc/lispref/commands.texi (Accessing Mouse): Fix documentation
    of last change.
---
 doc/lispref/commands.texi | 9 +++++----
 src/dispnew.c             | 9 ++++-----
 src/xdisp.c               | 4 ++--
 3 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/doc/lispref/commands.texi b/doc/lispref/commands.texi
index ad7ba1e8a82..82dca3548a6 100644
--- a/doc/lispref/commands.texi
+++ b/doc/lispref/commands.texi
@@ -2758,12 +2758,13 @@ to the entire window area including scroll bars, 
margins and fringes.
 
 @defopt mouse-prefer-closest-glyph
 If this variable is non-@code{nil}, the @code{posn-point} of a mouse
-position list will be set to the position of the glyph whose left most
-position is closest to the mouse pointer, as opposed to the position of
+position list will be set to the position of the glyph whose leftmost
+edge is the closest to the mouse click, as opposed to the position of
 the glyph underneath the mouse pointer itself.  For example, if
 @code{posn-at-x-y} is called with @var{x} set to @code{9}, which is
-contained within a character of width 10 positioned at column 0, the
-point saved within the mouse position list will be after that character.
+contained within a character of width 10 displayed at column 0, the
+point saved within the mouse position list will be @emph{after} that
+character, not @emph{before} it.
 @end defopt
 
 @node Accessing Scroll
diff --git a/src/xdisp.c b/src/xdisp.c
index 1de6fcfd172..540fdbb0b07 100644
--- a/src/xdisp.c
+++ b/src/xdisp.c
@@ -37513,10 +37513,10 @@ may be more familiar to users.  */);
   display_raw_bytes_as_hex = false;
 
   DEFVAR_BOOL ("mouse-fine-grained-tracking", mouse_fine_grained_tracking,
-    doc: /* Non-nil for pixel-wise mouse-movement.
+    doc: /* Non-nil for pixelwise mouse-movement.
 When nil, mouse-movement events will not be generated as long as the
 mouse stays within the extent of a single glyph (except for images).
-When nil and mouse-prefer-closest-glyph is non-nil, mouse-movement
+When nil and `mouse-prefer-closest-glyph' is non-nil, mouse-movement
 events will instead not be generated as long as the mouse stays within
 the extent of a single left/right half glyph (except for images).  */);
   mouse_fine_grained_tracking = false;



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/src/dispnew.c b/src/dispnew.c
index 821357c51c1..28f0eaeaa95 100644
--- a/src/dispnew.c
+++ b/src/dispnew.c
@@ -6823,12 +6823,11 @@ predicates which report frame's specific UI-related 
capabilities.  */);
               doc: /* Non-nil means put cursor in minibuffer, at end of any 
message there.  */);
 
   DEFVAR_BOOL ("mouse-prefer-closest-glyph", mouse_prefer_closest_glyph,
-              doc: /* Non-nil means mouse position lists are reported relative
-to the glyph closest to their coordinates.
+              doc: /* Non-nil means mouse click position is taken from glyph 
closest to click.
 
- When non-nil, mouse position lists will be reported with their
-`posn-point' set to the position of the glyph closest to the mouse
-pointer, instead of the glyph immediately under.  */);
+When non-nil, mouse position lists will report buffer position set to
+the position of the glyph that is the closest to the mouse pointer
+at the time of the click, instead of the glyph immediately under it.  */);
   mouse_prefer_closest_glyph = false;
 
   DEFVAR_LISP ("glyph-table", Vglyph_table,